<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//hr_HR

$LANG=array();


$LANG['backup'][0]="SQL Dump"; 
$LANG['backup'][1]="XML Dump"; 
$LANG['backup'][11]="Veličina"; 
$LANG['backup'][13]="Pogled/Prijenos"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Sada"; 
$LANG['backup'][21]="Datoteka već postoji"; 
$LANG['backup'][22]="Nemogu pronaći datoteku"; 
$LANG['backup'][23]="Mysql greška pokrenuta od"; 
$LANG['backup'][24]="Automatska redirekcija, opcija je klik"; 

$LANG['bookmark'][1]="podsjetnik"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Niste još spremili ni jedan podsjetnik."; 
$LANG['bookmark'][4]="Novi podsjetnik"; 
$LANG['bookmark'][5]="Javni podsjetnik"; 
$LANG['bookmark'][6]="Default view"; 

$LANG['buttons'][0]="Traži"; 
$LANG['buttons'][2]="Objavi"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Namjesti"; 
$LANG['buttons'][5]="Deinstaliraj"; 
$LANG['buttons'][6]="Obriši"; 
$LANG['buttons'][7]="Ažuriraj"; 
$LANG['buttons'][8]="Dodaj"; 
$LANG['buttons'][9]="Poveži"; 
$LANG['buttons'][10]="Prekini"; 
$LANG['buttons'][11]="Napred"; 
$LANG['buttons'][12]="Prijašnji"; 
$LANG['buttons'][13]="Nazad"; 
$LANG['buttons'][14]="Ažuriraj"; 
$LANG['buttons'][15]="Zakaži"; 
$LANG['buttons'][16]="Prazan"; 
$LANG['buttons'][17]="Izokrenite selekciju"; 
$LANG['buttons'][18]="Označi sve"; 
$LANG['buttons'][19]="Odznači sve"; 
$LANG['buttons'][20]="Premijesti"; 
$LANG['buttons'][21]="Obnovi"; 
$LANG['buttons'][22]="Čišćenje"; 
$LANG['buttons'][23]="Pokaži"; 
$LANG['buttons'][24]="Idi gore"; 
$LANG['buttons'][25]="Idi dolje"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Izvezi"; 
$LANG['buttons'][32]="Kraj"; 
$LANG['buttons'][33]="Kreni"; 
$LANG['buttons'][34]="Otkaži"; 
$LANG['buttons'][37]="Uvezi"; 
$LANG['buttons'][38]="Otključaj"; 
$LANG['buttons'][39]="Zamijeni"; 
$LANG['buttons'][40]="Pokaži sve"; 
$LANG['buttons'][41]="Aktiviraj"; 
$LANG['buttons'][42]="Deaktiviraj"; 
$LANG['buttons'][43]="Pregled"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Prije"; 
$LANG['buttons'][47]="Nakon"; 
$LANG['buttons'][48]="Transfer"; 
$LANG['buttons'][49]="Sačuvati"; 
$LANG['buttons'][50]="Testiraj"; 
$LANG['buttons'][51]="Spremi"; 
$LANG['buttons'][52]="Učitaj"; 
$LANG['buttons'][53]="Očisti"; 
$LANG['buttons'][55]="Prvi"; 
$LANG['buttons'][56]="Zadnji"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="S"; 
$LANG['calendarD'][1]="P"; 
$LANG['calendarD'][2]="U"; 
$LANG['calendarD'][3]="S"; 
$LANG['calendarD'][4]="Č"; 
$LANG['calendarD'][5]="P"; 
$LANG['calendarD'][6]="N"; 

$LANG['calendarDay'][0]="Nedelja"; 
$LANG['calendarDay'][1]="Ponedeljak"; 
$LANG['calendarDay'][2]="Utorak"; 
$LANG['calendarDay'][3]="Srijeda"; 
$LANG['calendarDay'][4]="Četvrtak"; 
$LANG['calendarDay'][5]="Petak"; 
$LANG['calendarDay'][6]="Subota"; 

$LANG['calendarM'][0]="Siječanj"; 
$LANG['calendarM'][1]="Veljača"; 
$LANG['calendarM'][2]="Ožujak"; 
$LANG['calendarM'][3]="Travanj"; 
$LANG['calendarM'][4]="Svibanj"; 
$LANG['calendarM'][5]="Lipanj"; 
$LANG['calendarM'][6]="Srpanj"; 
$LANG['calendarM'][7]="Kolovoz"; 
$LANG['calendarM'][8]="Rujan"; 
$LANG['calendarM'][9]="Listopad"; 
$LANG['calendarM'][10]="Studeni"; 
$LANG['calendarM'][11]="Prosinac"; 

$LANG['cartridges'][0]="Cartridge"; 
$LANG['cartridges'][7]="Cartridge nije nađen"; 
$LANG['cartridges'][9]="Nema Cartridge-a"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Model Cartridge-a"; 
$LANG['cartridges'][13]="Novi"; 
$LANG['cartridges'][14]="Korišten"; 
$LANG['cartridges'][15]="Istrošen"; 
$LANG['cartridges'][16]="Cartridge/i"; 
$LANG['cartridges'][20]="Novi"; 
$LANG['cartridges'][21]="Korišten"; 
$LANG['cartridges'][22]="Istrošen"; 
$LANG['cartridges'][24]="Dodaj datum"; 
$LANG['cartridges'][27]="On"; 
$LANG['cartridges'][29]="Trajanje"; 
$LANG['cartridges'][32]="Modeli kompatibilnih printera"; 
$LANG['cartridges'][33]="Korišteni Cartridge-i"; 
$LANG['cartridges'][34]="Nema slobodnog Cartridge-a"; 
$LANG['cartridges'][35]="Korišteni Cartidge-i"; 
$LANG['cartridges'][37]="Ribbon"; 
$LANG['cartridges'][39]="Printer brojač"; 
$LANG['cartridges'][40]="Prosječno vrijeme na skladištu"; 
$LANG['cartridges'][41]="Prosječno vrijeme korištenja"; 
$LANG['cartridges'][42]="Prosječan broj ispisa stranica"; 

$LANG['central'][2]="Posljednji"; 
$LANG['central'][4]="Nema događaja"; 
$LANG['central'][5]="Doma"; 
$LANG['central'][6]="Odjava"; 
$LANG['central'][7]="Pomoć"; 
$LANG['central'][8]="Dodaci"; 
$LANG['central'][9]="Vaši radni nalozi u obradi"; 
$LANG['central'][10]="Novi radni nalog"; 
$LANG['central'][12]="Osobni pogled"; 
$LANG['central'][13]="Globalni pogled"; 
$LANG['central'][14]="Grupni pogled"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Ne"; 
$LANG['choice'][1]="Da"; 

$LANG['common'][0]="Bez imena"; 
$LANG['common'][1]="Artikl"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Proizvođać"; 
$LANG['common'][6]="Naziv predloška"; 
$LANG['common'][7]="Odaberi predložak"; 
$LANG['common'][8]="Uredite predložak..."; 
$LANG['common'][9]="Dodaj predložak..."; 
$LANG['common'][10]="Tehničar zadužen"; 
$LANG['common'][11]="Ograničen pogled"; 
$LANG['common'][12]="Instalacija"; 
$LANG['common'][13]="Predložak"; 
$LANG['common'][14]="Predlošci"; 
$LANG['common'][15]="Lokacija"; 
$LANG['common'][16]="Prezime"; 
$LANG['common'][17]="Vrsta"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Serijski broj"; 
$LANG['common'][20]="Inventarski broj"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Zadatak uspješan"; 
$LANG['common'][24]="Nema selektiranog elementa ili je loše definirana akcija"; 
$LANG['common'][25]="Komentar"; 
$LANG['common'][26]="Zadnja nadogradnja"; 
$LANG['common'][27]="Datum"; 
$LANG['common'][28]="Obrisano"; 
$LANG['common'][29]="Plugins/dodaci"; 
$LANG['common'][30]="Novi artikl"; 
$LANG['common'][31]="Prazni predložak"; 
$LANG['common'][32]="Osobine"; 
$LANG['common'][33]="Ukupno"; 
$LANG['common'][34]="Korisnik"; 
$LANG['common'][35]="Grupa"; 
$LANG['common'][36]="Kategorija"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Duplicirajte element toliko puta koliko ima konekcija"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Email alarm"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Ime"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Napredak"; 
$LANG['common'][48]="Srednje ime"; 
$LANG['common'][49]="Ništa"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Kompletno ime"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Popis"; 
$LANG['common'][54]="Artikl nije nađen"; 
$LANG['common'][55]="Jeste li sigurni da želite obrisati?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Naslov"; 
$LANG['common'][58]="Maksimalna vrijednost"; 
$LANG['common'][59]="Globalno"; 
$LANG['common'][60]="Aktivno"; 
$LANG['common'][61]="Nepoznata greška"; 
$LANG['common'][62]="Ostalo"; 
$LANG['common'][63]="Greška"; 
$LANG['common'][64]="Upravitelj"; 
$LANG['common'][65]="Sučelje"; 
$LANG['common'][66]="Sve"; 
$LANG['common'][67]="Ostali"; 
$LANG['common'][68]="Polegnuto"; 
$LANG['common'][69]="Portret"; 
$LANG['common'][70]="Artikl uspješno dodan"; 
$LANG['common'][71]="Objekt uspješno nadograđen"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Objekt uspješno obnovljen"; 
$LANG['common'][75]="Nemate prava izmjene ovog artikla"; 
$LANG['common'][76]="Javno"; 
$LANG['common'][77]="Privatno"; 
$LANG['common'][78]="Postavi javno"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Tijekom učitavanja..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Zabranjena promijena. Nađeni vezani artikli."; 
$LANG['common'][85]="Promijeni vidljivost"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nova kartica"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Veličina"; 
$LANG['computers'][1]="Slobodno u postocima"; 
$LANG['computers'][2]="Slobodnog prostora"; 
$LANG['computers'][3]="Globalna veličina"; 
$LANG['computers'][4]="Datotečni sustav"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Dodaj 'volume'"; 
$LANG['computers'][8]="Veličine"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Dodano"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Nema priključenog monitora"; 
$LANG['computers'][38]="Nema priključenog printera"; 
$LANG['computers'][39]="Printer"; 
$LANG['computers'][40]="Monitor"; 
$LANG['computers'][46]="Uređaji"; 
$LANG['computers'][47]="Nema priključenog uređaja"; 
$LANG['computers'][48]="Lokacija ažurirana. Uređaj premješten na istu lokaciju."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Korisnik ili grupa ažurirani. Priključeni uređaj premješten sa istim vrijednostima."; 
$LANG['computers'][51]="Izvor nadogradnje"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Nema priljučenog telefona"; 
$LANG['computers'][55]="Telefon"; 
$LANG['computers'][56]="Status ažuriran. Priključeni uređaj ažuriran koristeći ovaj status."; 

$LANG['connect'][0]="Direktna konekcija"; 
$LANG['connect'][1]="Nije konektiran."; 
$LANG['connect'][15]="Automatski ažuriraj sljedeći uređaj"; 
$LANG['connect'][16]="Upozorenje!! Navedeni dio ne odgovara"; 

$LANG['consumables'][0]="Potrošni"; 
$LANG['consumables'][1]="Na skladištu"; 
$LANG['consumables'][2]="Reference"; 
$LANG['consumables'][7]="Potrošni nije pronađen"; 
$LANG['consumables'][9]="Nije potrošni"; 
$LANG['consumables'][12]="Potršni tip"; 
$LANG['consumables'][13]="Novo"; 
$LANG['consumables'][15]="Korišten"; 
$LANG['consumables'][16]="Potrošni"; 
$LANG['consumables'][20]="Novo"; 
$LANG['consumables'][22]="Korišten"; 
$LANG['consumables'][23]="Stanje"; 
$LANG['consumables'][26]="Datum korištenja"; 
$LANG['consumables'][32]="Daj"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Lokacija skladišta"; 
$LANG['consumables'][37]="Nazad na skladište"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Dodaj novu komponentu"; 
$LANG['devices'][1]="HDD"; 
$LANG['devices'][2]="Grafička kartica"; 
$LANG['devices'][3]="Mrežna kartica"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Matična ploča"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Zvučna kartica"; 
$LANG['devices'][19]="Uređaji"; 
$LANG['devices'][20]="Kontroler"; 
$LANG['devices'][21]="Ostale komponente"; 
$LANG['devices'][22]="Kučište"; 
$LANG['devices'][23]="Napajanje"; 
$LANG['devices'][24]="standardno"; 
$LANG['devices'][25]="Dodaj komponentu"; 
$LANG['devices'][26]="Obriši komponentu"; 

$LANG['device_case'][0]="Veličina"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Sposobnost pisanja"; 
$LANG['device_drive'][1]="Brzina"; 

$LANG['device_hdd'][0]="Rpm - broj okretaja"; 
$LANG['device_hdd'][1]="Spremnik"; 
$LANG['device_hdd'][4]="Kapacitet"; 

$LANG['device_iface'][0]="Flow"; 
$LANG['device_iface'][2]="Mac adresa"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Snaga"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvencija"; 
$LANG['device_ram'][2]="Veličina"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Datoteka"; 
$LANG['document'][3]="Zaglavlje"; 
$LANG['document'][4]="MIME"; 
$LANG['document'][7]="Tip dokumenta"; 
$LANG['document'][9]="Ekstenzija"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Autorizirani download"; 
$LANG['document'][15]="Download"; 
$LANG['document'][16]="Dodaj dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Pridruženi artikli"; 
$LANG['document'][21]="Pridruži dokument"; 
$LANG['document'][22]="Trenutna datoteka"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Uspješno brisanje datoteke"; 
$LANG['document'][25]="Nemogu obrisati datoteku"; 
$LANG['document'][26]="Datoteka je valjana. Upload je uspješan."; 
$LANG['document'][27]="Potencijalna opasnost, ili je datoteka prevelika. Micanje privremene datoteke neuspjelo."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Neuspješno kreiranje mape"; 
$LANG['document'][30]="Potvrdite da posjedujete valjane ovlasti"; 
$LANG['document'][31]="Mapa za dokumente ne postoji"; 
$LANG['document'][32]="Neovlašten tip dokumenta"; 
$LANG['document'][33]="Web veza"; 
$LANG['document'][34]="Kreiraj mapu"; 
$LANG['document'][35]="Upload mapa ne postoji"; 
$LANG['document'][36]="Koristite FTP instaliranu datoteku"; 
$LANG['document'][37]="Datoteka nije raspoloživa"; 
$LANG['document'][38]="Datoteka nije nađena"; 
$LANG['document'][39]="Micanje dokumenta uspješno"; 
$LANG['document'][40]="Micanje datoteke nije uspjelo"; 
$LANG['document'][41]="Kopiranje dokumenta uspješno"; 
$LANG['document'][42]="Dodano od"; 
$LANG['document'][43]="Nepoznata datoteka"; 
$LANG['document'][44]="Krivi naziv datoteke"; 
$LANG['document'][45]="Neovlašten pristup datoteci"; 
$LANG['document'][46]="Greška kod slanja datoteke (vjerojatno prevelika)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Subjekt"; 
$LANG['entity'][2]="Root subjekt"; 
$LANG['entity'][3]="Pridruži subjektu"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatsko dodijeljivanje korisnika"; 
$LANG['entity'][7]="granata struktura"; 
$LANG['entity'][8]="Po subjektu"; 
$LANG['entity'][9]="Pod subjekti"; 
$LANG['entity'][10]="Odaberite željeni subjekt"; 
$LANG['entity'][11]="da vidite subjekt i njegov pod-subjekt"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Servis"; 
$LANG['event'][3]="Nivo"; 
$LANG['event'][4]="Poruka"; 
$LANG['event'][18]="Polje"; 
$LANG['event'][19]="Nadogradnja"; 
$LANG['event'][20]="Nema povijesti"; 

$LANG['financial'][1]="Ugovor"; 
$LANG['financial'][2]="Ima život."; 
$LANG['financial'][3]="Financijske informacije"; 
$LANG['financial'][4]="Broj"; 
$LANG['financial'][5]="Vrijednost"; 
$LANG['financial'][6]="Tip ugovora"; 
$LANG['financial'][8]="Trajanje"; 
$LANG['financial'][9]="godina(e)"; 
$LANG['financial'][10]="Bilješka"; 
$LANG['financial'][11]="Rok plaćanja"; 
$LANG['financial'][13]="Broj računa"; 
$LANG['financial'][14]="Datum kupnje"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Informacije o garanciji"; 
$LANG['financial'][18]="Broj narudžbe"; 
$LANG['financial'][19]="Isporučeno od"; 
$LANG['financial'][20]="Imobilizacijski broj"; 
$LANG['financial'][21]="Vrijednost"; 
$LANG['financial'][22]="Tip amortizacije"; 
$LANG['financial'][23]="Vrijeme amortizacije"; 
$LANG['financial'][24]="Dodaj kontakt..."; 
$LANG['financial'][25]="Dodaj dobavljača..."; 
$LANG['financial'][26]="Dobavljač"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Dodaj kontakt"; 
$LANG['financial'][36]="Dodaj ugovor"; 
$LANG['financial'][42]="Komercijalni"; 
$LANG['financial'][43]="Tehničar"; 
$LANG['financial'][44]="Adresa"; 
$LANG['financial'][45]="Web stranica"; 
$LANG['financial'][46]="Pripadajući kontakt"; 
$LANG['financial'][47]="Linearno"; 
$LANG['financial'][48]="Smanjenje"; 
$LANG['financial'][50]="Najam"; 
$LANG['financial'][51]="Rentanje"; 
$LANG['financial'][52]="Lizing"; 
$LANG['financial'][53]="Osiguranje"; 
$LANG['financial'][54]="Podrška opremi"; 
$LANG['financial'][55]="Programska podrška"; 
$LANG['financial'][56]="Servis od"; 
$LANG['financial'][57]="mjesec"; 
$LANG['financial'][59]="Sati podrške"; 
$LANG['financial'][60]="na tjedan"; 
$LANG['financial'][61]="U Subotu"; 
$LANG['financial'][62]="Nedelje i praznici"; 
$LANG['financial'][65]="Pripadajući dobavljač"; 
$LANG['financial'][66]="Pripadajući ugovor"; 
$LANG['financial'][68]="Aktivirajte financijske informacije"; 
$LANG['financial'][69]="Trajanje ugovora"; 
$LANG['financial'][76]="Početni datum"; 
$LANG['financial'][77]="Amortizacijski koeficijent"; 
$LANG['financial'][78]="Garancija..."; 
$LANG['financial'][79]="Tip trećeg proizvođaća."; 
$LANG['financial'][80]="Datum isteka garancije"; 
$LANG['financial'][81]="Obračunata vrijednost"; 
$LANG['financial'][82]="Broj računa"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Za ovaj tip elementa, financijske informacije su samo ogledne te pokazuju način na koji ih trebate dodati."; 
$LANG['financial'][85]="Traženi artikl nije nađen"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Proračun"; 
$LANG['financial'][88]="Vrijedi do:"; 
$LANG['financial'][89]="TCO (vrijednost + popratni troškovi)"; 
$LANG['financial'][90]="Mjesečni TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Ugovor istekao - u zadnjih 30 dana"; 
$LANG['financial'][94]="Ugovor ističe za manje od 7 dana"; 
$LANG['financial'][95]="Ugovor ističe za manje od 30 dana"; 
$LANG['financial'][96]="Ugovor počinje za manje od 7 dana."; 
$LANG['financial'][97]="Ugovor počinje za manje od 30 dana."; 
$LANG['financial'][98]="Istek"; 
$LANG['financial'][99]="Datum isteka + obavijest"; 
$LANG['financial'][100]="Poštanski broj"; 
$LANG['financial'][101]="Grad"; 
$LANG['financial'][102]="Stanje"; 
$LANG['financial'][103]="Država"; 
$LANG['financial'][104]="Pripadajući artikli"; 
$LANG['financial'][105]="Prešutan"; 
$LANG['financial'][106]="Ekspres"; 
$LANG['financial'][107]="Obnova"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="sat(i)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Vrlo visoko"; 
$LANG['help'][4]="Visoko"; 
$LANG['help'][5]="Srednje"; 
$LANG['help'][6]="Nisko"; 
$LANG['help'][7]="Vrlo nisko"; 
$LANG['help'][8]="Obavijestite me o pokrenutim akcijama"; 
$LANG['help'][11]="Moj e-mail"; 
$LANG['help'][14]="Potvrdi poruku"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Vaša poruka je uspješno poslana, Vaš zahtjev je u datoteci."; 
$LANG['help'][19]="Hvala što koristite naš automatski helpdesk sustav."; 
$LANG['help'][22]="Potražite ID od Vašeg računala"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Hardware model"; 
$LANG['help'][25]="Računalo"; 
$LANG['help'][26]="Mrežni uređaj"; 
$LANG['help'][27]="Printer"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Uređaj"; 
$LANG['help'][30]="Osnovno"; 
$LANG['help'][31]="Programi"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Nema naziva u radnom nalogu, molim pokušajte ponovno."; 
$LANG['help'][41]="Nema kategorija za Vaš radni nalog, molim pokušajte ponovno."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Instalacija ili nadogradnja GLPI-a"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Instalacija"; 
$LANG['install'][4]="Nadogradi"; 
$LANG['install'][5]="Provjera kompatibilnosti vašeg sustava za pokretanje GLPI-a"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Rezultat"; 
$LANG['install'][8]="Testiranje PHP parsera"; 
$LANG['install'][9]="Morate instalirati najmanje PHP5."; 
$LANG['install'][10]="GLPI nije kompatibilan sa opcijom zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP verzija je najmanje 5.x - Odlično !"; 
$LANG['install'][12]="Test sesije"; 
$LANG['install'][13]="Vaš PHP parser nije kompajliran sa opcijom sesija !"; 
$LANG['install'][14]="Podrška sesije je raspoloživa - Odlično !"; 
$LANG['install'][15]="Budite sigurni da je podrška za sesije uključena u Vašem php.ini"; 
$LANG['install'][16]="Provjera prava pisanja za 'dump' datoteka"; 
$LANG['install'][17]="Datoteka nemože biti kreirana."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Datoteka je kreirana, ali se nemože obrisati."; 
$LANG['install'][20]="Datoteka i mapa su kreirani i obrisani - Odlično !"; 
$LANG['install'][21]="Provjera prava pisanja za datoteke dokumenata"; 
$LANG['install'][22]="Datoteka je kreirana - Odlično !"; 
$LANG['install'][23]="Provjera prava pisanja za postavke datoteka"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Nastaviti ?"; 
$LANG['install'][26]="Nastaviti"; 
$LANG['install'][27]="Pokušajte ponovo"; 
$LANG['install'][28]="Instalacija baze"; 
$LANG['install'][29]="Parametri konekcije na bazu"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Testiranje veze sa bazom"; 
$LANG['install'][35]="Nemogu se spojiti na bazu"; 
$LANG['install'][36]="Server odgovorio"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Molim odaberite bazu:"; 
$LANG['install'][39]="Kreirajte novu bazu ili odaberite drugu postojeću:"; 
$LANG['install'][40]="Molim odaberite bazu za nadogradnju:"; 
$LANG['install'][41]="Nemoguće korištenje baze:"; 
$LANG['install'][43]="OK - baza je inicijalizirana"; 
$LANG['install'][47]="Nemoguća izrada datoteke za instalaciju baze"; 
$LANG['install'][48]="Greška pri kreiranju baze !"; 
$LANG['install'][49]="Niste odabrali bazu !"; 
$LANG['install'][50]="Provjera prava pisanja za sesije datoteka"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Testiranja zapisivanja log datoteke"; 
$LANG['install'][55]="Završena instalacija"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="glpi/glpi za administratorski pristup"; 
$LANG['install'][59]="tech/tech za korisnika tehničara"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Koristi GLPI"; 
$LANG['install'][65]="Test ekstenzije magic_quotes_sybase"; 
$LANG['install'][66]="GLPI ne radi sa magic_quotes_sybase opcijom ; Molim isključite je i pokušajte ponovo"; 
$LANG['install'][67]="Opcija magic_qutes_sybase nije aktivna na Vašem serveru - Odlično !"; 
$LANG['install'][68]="Testiranje auto starta sesije"; 
$LANG['install'][69]="session.auto_start je aktivno. Vidite .htaccess datoteku u GLPI korijenskoj mapi za više informacija."; 
$LANG['install'][70]="Nemogućnost kreiranja veze između baze i datoteke, provjerite ovlasti."; 
$LANG['install'][71]="Mysql test ekstenzija."; 
$LANG['install'][72]="Morate kompajlirati Vaš php sa Mysql ekstenzijom"; 
$LANG['install'][73]="U redu - funkcija mysql_query() postoji - Odlično !"; 
$LANG['install'][74]="Test Session_use_trans_sid je aktivan"; 
$LANG['install'][75]="Morate deaktivirati opciju Session_use_trans_id u php.ini."; 
$LANG['install'][76]="OK - sesija radi (nema problema sa trans_id) - Odlično !"; 
$LANG['install'][77]="Korak"; 
$LANG['install'][81]="Početak instalacije"; 
$LANG['install'][82]="Baza je kreirana"; 
$LANG['install'][85]="Funkcionalnost je nađena - Odlično !"; 
$LANG['install'][86]="Testiranje alocirane memorije"; 
$LANG['install'][87]="Alocirana memorija:"; 
$LANG['install'][88]="Minimum od 64MB je standardno potrebno za GLPI."; 
$LANG['install'][89]="Odlično !"; 
$LANG['install'][90]="Povečajte parametar memory_limit u php.ini datoteci."; 
$LANG['install'][91]="Alocirana memorija > 64M"; 
$LANG['install'][92]="Licenca"; 
$LANG['install'][93]="Pročitao sam i PRISTAJEM na uvjete licence napisane ispod."; 
$LANG['install'][94]="Pročitao sam i NE PRISTAJEM na licencne uvjete napisane ispod"; 
$LANG['install'][95]="Neograničena memorija"; 
$LANG['install'][96]="Neograničena memorija"; 
$LANG['install'][97]="Provjera ovlasti na mapu:"; 
$LANG['install'][99]="Provjera prava pisanja za 'cache' datoteke"; 
$LANG['install'][100]="Mapa nemože biti kreirana."; 
$LANG['install'][101]="Mapa je kreirana ali nemože biti obrisana."; 
$LANG['install'][102]="Testiranje json funkcije"; 
$LANG['install'][103]="GLPI ne može raditi ispravno bez json_encode i json_decode funkcije"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="od"; 
$LANG['job'][4]="Tražitelj"; 
$LANG['job'][5]="Dodijeljen na"; 
$LANG['job'][6]="Tehničar"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Opis problema/akcije"; 
$LANG['job'][12]="Nema praćenja za ovaj ticket"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Email praćenje"; 
$LANG['job'][20]="Ukupno trajanje"; 
$LANG['job'][21]="Sat(i)"; 
$LANG['job'][22]="Minuta(e)"; 
$LANG['job'][29]="Dodaj novo praćenje"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Trajanje"; 
$LANG['job'][32]="Ništa"; 
$LANG['job'][33]="Prazan opis"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planiranje"; 
$LANG['job'][37]="Ukupno"; 
$LANG['job'][38]="Ticket"; 
$LANG['job'][39]="Nadogradi praćenje"; 
$LANG['job'][40]="Vremenski troškovi"; 
$LANG['job'][41]="Fiksni troškovi"; 
$LANG['job'][42]="Vrijednost materijala"; 
$LANG['job'][43]="Ukupni troškovi"; 
$LANG['job'][44]="Izvor zahtjeva"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Status"; 
$LANG['joblist'][1]="Samo moji"; 
$LANG['joblist'][2]="Prioritet"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Naslovljeno"; 
$LANG['joblist'][6]="Opis"; 
$LANG['joblist'][7]="Novi radni nalog za uređaj..."; 
$LANG['joblist'][8]="Nije nađen radni nalog"; 
$LANG['joblist'][9]="Novi"; 
$LANG['joblist'][10]="Zatvoreno (riješeno)"; 
$LANG['joblist'][11]="Otvoren od"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Zatvoreno (nije riješeno)"; 
$LANG['joblist'][18]="Obrada (naslovljena)"; 
$LANG['joblist'][19]="Obrada (planirana)"; 
$LANG['joblist'][21]="Obrada"; 
$LANG['joblist'][26]="Na čekanju"; 
$LANG['joblist'][27]="E-mail za prosljeđivanje"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ - Često postavljana pitanja"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Odaberite kategoriju za ovaj artikl:"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Uredi ovaj artikl"; 
$LANG['knowbase'][9]="Obriši ovaj artikl"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Administrator"; 
$LANG['knowbase'][13]="Naziv kategorije"; 
$LANG['knowbase'][14]="Tema"; 
$LANG['knowbase'][15]="Sadržaj"; 
$LANG['knowbase'][24]="Pristup na često postavljana pitanja"; 
$LANG['knowbase'][26]="Pogled"; 
$LANG['knowbase'][27]="Uključi"; 
$LANG['knowbase'][29]="Zadnji unosi"; 
$LANG['knowbase'][30]="Najpopularnija pitanja"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Sinkronizacija već uvezenih korisnika"; 
$LANG['ldap'][2]="Uvezi nove korisnike"; 
$LANG['ldap'][3]="Nema korisnika za uvoz"; 
$LANG['ldap'][4]="LDAP odabir mapa"; 
$LANG['ldap'][5]="Odaberite LDAP mapu za uvoz korisnika"; 
$LANG['ldap'][6]="Nemogućnost spajanja na LDAP mapu"; 
$LANG['ldap'][7]="LDAP mapa nije definirana u GLPI-u"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Testiranje konekcije prema LDAP mapi"; 
$LANG['ldap'][12]="Sinkronizacija"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="u GLPI"; 
$LANG['ldap'][15]="Sinhroniziraj"; 
$LANG['ldap'][16]="Prekonfiguracija"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Repliciraj"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Glavni server"; 
$LANG['ldap'][22]="Repliciraj"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Uvezi nove grupe"; 
$LANG['ldap'][25]="Nema grupe za uvoz"; 
$LANG['ldap'][30]="Kako LDAP nadimci trebaju biti korišteni"; 
$LANG['ldap'][31]="Nikad neupućen (standardno)"; 
$LANG['ldap'][32]="Uvijek neupućen"; 
$LANG['ldap'][33]="Neupućen tijekom traženja (ali ne kod lociranja)"; 
$LANG['ldap'][34]="Neupućen kod lociranja (ne tijekom traženja)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Veza ili ime datoteke"; 
$LANG['links'][4]="Pridodan tip opreme HW"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Veza nije definirana"; 
$LANG['links'][9]="Sadržaj datoteke"; 

$LANG['log'][1]="sistem"; 
$LANG['log'][16]="planiranje"; 
$LANG['log'][18]="komponente"; 
$LANG['log'][20]="artikl dodan"; 
$LANG['log'][21]="nadogradi artikl"; 
$LANG['log'][22]="obriši artikl"; 
$LANG['log'][23]="obnovi artikl"; 
$LANG['log'][24]="briši artikl"; 
$LANG['log'][26]="isključi artikl"; 
$LANG['log'][27]="konektiranje artikla"; 
$LANG['log'][28]="modifikacija komponente"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="pridružite tip"; 
$LANG['log'][31]="obriši tip"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="obriši vezu sa artiklom"; 
$LANG['log'][34]="dodaj vezu na dobavljača"; 
$LANG['log'][35]="obriši vezu sa dobavljačem"; 
$LANG['log'][40]="IP konekcija"; 
$LANG['log'][41]="konektiranje neuspjelo"; 
$LANG['log'][42]="Rezervacija"; 
$LANG['log'][44]="Zaglavlje"; 
$LANG['log'][45]="Uspješno"; 
$LANG['log'][46]="Neuspjelo"; 
$LANG['log'][48]="dodaj korisnika grupi"; 
$LANG['log'][49]="brisanje korisnika iz grupe"; 
$LANG['log'][55]="konekcije"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="dodaj korisnika subjektu"; 
$LANG['log'][62]="kompletno micanje korisnika"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="pravila"; 
$LANG['log'][66]="Sigurnost"; 
$LANG['log'][67]="modifikacija bilješke"; 
$LANG['log'][70]="mrežni port dodan"; 
$LANG['log'][71]="nekoliko mrežnih portova dodano"; 
$LANG['log'][73]="mrežni port obrisan"; 
$LANG['log'][74]="nekoliko mrežnih portova obrisano"; 
$LANG['log'][75]="mrežni port maknut"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="dodaj verziju"; 
$LANG['log'][83]="modifikacija verzije"; 
$LANG['log'][84]="brisanje verije"; 
$LANG['log'][85]="dodaj licencu"; 
$LANG['log'][86]="modifikacija licence"; 
$LANG['log'][87]="brisanje licence"; 
$LANG['log'][88]="dodaj toner"; 
$LANG['log'][89]="dodavanje potrošnog"; 
$LANG['log'][90]="isključenje tonera"; 
$LANG['log'][91]="isključenje potrošnog"; 
$LANG['log'][92]="obnova tonera"; 
$LANG['log'][93]="obnova potrošnog"; 
$LANG['log'][94]="nadogradnja tonera"; 
$LANG['log'][95]="instalacija tonera"; 
$LANG['log'][96]="deinstalacija tonera"; 
$LANG['log'][97]="potrošni nije za korisnika"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Zadnje prijavljen/a"; 
$LANG['login'][1]="Ponovno se prijavite"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Pristup zabranjen"; 
$LANG['login'][6]="Prijava"; 
$LANG['login'][7]="Zaporka"; 
$LANG['login'][8]="Isprazni korisničko ime i zaporku"; 
$LANG['login'][9]="Nije još autentificirano"; 
$LANG['login'][10]="Autentifikacija"; 
$LANG['login'][11]="Korisnik nije ovlašten za pristup u GLPI"; 
$LANG['login'][12]="Neispravno korisničko ime ili zaporka"; 
$LANG['login'][13]="Korisničko polje je prazno"; 
$LANG['login'][14]="nepoznat korisnik"; 
$LANG['login'][15]="Korisnik nije nađen ili je nađeno nekoliko korisnika"; 
$LANG['login'][16]="Neuspješna autentifikacija u LDAP"; 
$LANG['login'][18]="Interna baza GLPI-a"; 
$LANG['login'][20]="Nemate pristup u aplikaciju, Vaš račun je deaktiviran i odstranjen"; 
$LANG['login'][21]="Testiraj konekciju do IMAP/POP poslužitelja"; 
$LANG['login'][22]="Test uspješan"; 
$LANG['login'][23]="Test neuspješan"; 
$LANG['login'][24]="Zadnji datum prijave"; 
$LANG['login'][25]="Nemate prava za pristup"; 
$LANG['login'][26]="Molim aktivirajte JavaScript funkciju u Vašem pregledniku"; 
$LANG['login'][27]="Morate prihvatiti 'cookies', da se omogući pristup aplikaciji"; 
$LANG['login'][30]="Promjena autentifikacijske metode"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Autentifikacija na GLPI bazu"; 
$LANG['login'][33]="Autentifikacija na IMAP/POP poslužitelj"; 

$LANG['mailgate'][0]="Mail primatelj"; 
$LANG['mailgate'][2]="Dohvati email tickete sad"; 
$LANG['mailgate'][3]="Broj raspoloživih i primljenih email poruka"; 
$LANG['mailgate'][4]="mbstring ekstenzija nije nađena. Upozorenje, koji se charset koristi."; 
$LANG['mailgate'][5]="Neispravna datoteka u privitku"; 
$LANG['mailgate'][6]="Prevelika datoteka u privitku"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Opis ticketa"; 
$LANG['mailing'][10]="Praćenje novog ticketa"; 
$LANG['mailing'][12]="Ticket naslovljen na"; 
$LANG['mailing'][14]="Ažuriranje kategorije ticketa"; 
$LANG['mailing'][15]="Ažuriranje prioriteta ticketa"; 
$LANG['mailing'][17]="Ažuriranje artikla u ticketu"; 
$LANG['mailing'][18]="Ažuriranje autora ticketa"; 
$LANG['mailing'][19]="Nova rezervacija"; 
$LANG['mailing'][20]="Ažuriranje grupe ticketa"; 
$LANG['mailing'][21]="Promijeni izvor ticketa"; 
$LANG['mailing'][23]="Modifikacija rezervacije"; 
$LANG['mailing'][26]="Dodaj dokument :"; 
$LANG['mailing'][27]="Ažuriranje statusa ticketa"; 
$LANG['mailing'][29]="Rezervacija otkazana"; 
$LANG['mailing'][30]="Ažuriranje ticketa"; 
$LANG['mailing'][31]="Ovo je test email, da se vidi ispravnost sustava"; 
$LANG['mailing'][32]="Mail test"; 
$LANG['mailing'][33]="Toner alarm"; 
$LANG['mailing'][35]="Alarm za potrošni:"; 
$LANG['mailing'][36]="Alarm na potrošni"; 
$LANG['mailing'][37]="Ugovor unešen u najavljeno vrijeme:"; 
$LANG['mailing'][39]="Alarm na ugovor"; 
$LANG['mailing'][40]="Artikl stigao pred kraj garancije"; 
$LANG['mailing'][41]="Alarm na financijske informacije"; 
$LANG['mailing'][42]="Promijene u vrijednosti stanice"; 
$LANG['mailing'][43]="Promijene u fiksnim troškovima"; 
$LANG['mailing'][44]="Promijene u vrijednosti materijala"; 
$LANG['mailing'][45]="Promijeni naziv ticketa"; 
$LANG['mailing'][46]="Promijeni naziv ticketa"; 
$LANG['mailing'][47]="Greška u slanju email-a"; 
$LANG['mailing'][48]="Promijene u datumu otvaranja"; 
$LANG['mailing'][49]="Promijene u datumu zatvaranja"; 
$LANG['mailing'][50]="Promijeni primatelja ticketa"; 
$LANG['mailing'][51]="Istekla licenca :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Nema definirane kategorije"; 
$LANG['mailing'][101]="Praćenje email-a je uključeno"; 
$LANG['mailing'][102]="Praćenje email-a je isključeno"; 
$LANG['mailing'][104]="Trajanje praćenja"; 
$LANG['mailing'][105]="Nije dodijeljen"; 
$LANG['mailing'][107]="Ništa"; 
$LANG['mailing'][109]="Nema grupe"; 
$LANG['mailing'][110]="Krivi email"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Računala"; 
$LANG['Menu'][1]="Mreža"; 
$LANG['Menu'][2]="Printeri"; 
$LANG['Menu'][3]="Monitori"; 
$LANG['Menu'][4]="Programi"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Izvješća"; 
$LANG['Menu'][11]="Postavke"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistika"; 
$LANG['Menu'][14]="Korisnici"; 
$LANG['Menu'][15]="Administracija"; 
$LANG['Menu'][16]="Uređaji"; 
$LANG['Menu'][17]="Rezervacije"; 
$LANG['Menu'][18]="Alati"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Toner(i)"; 
$LANG['Menu'][22]="Kontakti"; 
$LANG['Menu'][23]="Dobavljači"; 
$LANG['Menu'][24]="Financijske informacije"; 
$LANG['Menu'][25]="Ugovori"; 
$LANG['Menu'][26]="Upravljanje"; 
$LANG['Menu'][27]="Dokumenti"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planiranje"; 
$LANG['Menu'][30]="Log"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Potrošni"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoni"; 
$LANG['Menu'][35]="Profili"; 
$LANG['Menu'][36]="Grupe"; 
$LANG['Menu'][37]="Subjekti"; 
$LANG['Menu'][38]="Inventar"; 
$LANG['Menu'][39]="Primatelji"; 
$LANG['Menu'][40]="Oznake"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Zvučnici"; 
$LANG['monitors'][18]="Oznaka"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Veličina"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivotiranje"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Mrežni port"; 
$LANG['networking'][13]="mrežni portovi nađeni"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Spojen na"; 
$LANG['networking'][19]="Dodaj mrežni port..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="na"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Port"; 
$LANG['networking'][46]="Dodaj nekoliko portova..."; 
$LANG['networking'][47]="Od"; 
$LANG['networking'][48]="Do"; 
$LANG['networking'][51]="Mrežna točka"; 
$LANG['networking'][55]="Pridruži VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Odaberi MAC adresu na listi ili je specificirajte ispod"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Opcije uvoza"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Izostavi sljedeće znakove (separator $, ništa za sve)"; 
$LANG['ocsconfig'][10]="Masovni uvoz"; 
$LANG['ocsconfig'][11]="Nema uvoza"; 
$LANG['ocsconfig'][12]="Uvoz jedinice"; 
$LANG['ocsconfig'][13]="Uvoz jedinice: sve uvezi 'kako je'"; 
$LANG['ocsconfig'][14]="Masovni uvoz: sve je uvezeno ali je materijal opće uređen (bez duplih unosa)"; 
$LANG['ocsconfig'][15]="Nema uvoza: plugin neće uvesti ove elemente"; 
$LANG['ocsconfig'][16]="Početno stanje"; 
$LANG['ocsconfig'][17]="Limitiraj uvoz sljedećih znakova (separator $, ništa za sve)"; 
$LANG['ocsconfig'][18]="Nađi, provjeri da su duplikati obrađeni u OCSNG"; 
$LANG['ocsconfig'][19]="Uvoz jedinice po serijskom broju"; 
$LANG['ocsconfig'][27]="Generane informacije"; 
$LANG['ocsconfig'][36]="Modemi"; 
$LANG['ocsconfig'][37]="Portovi"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registry"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Ponašanje kod isključenja"; 
$LANG['ocsconfig'][49]="Smeće"; 
$LANG['ocsconfig'][50]="Brisanje"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="prazan"; 
$LANG['ocsconfig'][57]="jednak"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS inventar NG"; 
$LANG['ocsng'][1]="Sinkronizirana računala su već uvezena"; 
$LANG['ocsng'][2]="Uvezi novo računalo"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Poveži nova OCS računala u postojeća GLPI računala"; 
$LANG['ocsng'][5]="Uvezi nova računala"; 
$LANG['ocsng'][6]="Automatska nadogradnja"; 
$LANG['ocsng'][7]="Uvezeno iz OCSNG"; 
$LANG['ocsng'][8]="Uvoz uspješan"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Ažuriraj računala"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Uvezi datum u GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Nema zaključanog polja"; 
$LANG['ocsng'][16]="Zaključano polje"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Pažnja! Uvezeni podaci (vidi konfiguraciju) prepisaće postojeće podatke"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Forsiraj sinkronizaciju"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Zaključan monitor"; 
$LANG['ocsng'][32]="Zaključan uređaj (i)"; 
$LANG['ocsng'][34]="Zaključan printer"; 
$LANG['ocsng'][36]="Putanja subjekta"; 
$LANG['ocsng'][37]="Aktiviraj pregled"; 
$LANG['ocsng'][38]="Onemogući pregled"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Način ručnog uvoza"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Zaključan IP"; 
$LANG['ocsng'][52]="Zaključan program(i)"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Disk zaključan"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="Prema"; 
$LANG['pager'][2]="od"; 
$LANG['pager'][3]="od"; 
$LANG['pager'][4]="Pokaži"; 
$LANG['pager'][5]="artikl"; 

$LANG['peripherals'][18]="Brand"; 
$LANG['peripherals'][31]="Globalno upravljanje"; 
$LANG['peripherals'][32]="Upravljanje jedinicama"; 
$LANG['peripherals'][33]="Tip upravljanja"; 

$LANG['phones'][18]="Model"; 
$LANG['phones'][36]="Napajanje"; 
$LANG['phones'][38]="Slušalice"; 
$LANG['phones'][39]="Zvučnik"; 
$LANG['phones'][40]="Broj linija"; 

$LANG['planning'][0]="Traženi korisnik već ima zakazano za to vrijeme."; 
$LANG['planning'][1]="Greška pri unosu datuma. Početni datum je kasniji od završnog datuma."; 
$LANG['planning'][5]="Dan"; 
$LANG['planning'][6]="Tjedan"; 
$LANG['planning'][8]="Praćenje"; 
$LANG['planning'][9]="Od"; 
$LANG['planning'][10]="iCal"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// Sinkronizacija"; 
$LANG['planning'][14]="Mjesec"; 
$LANG['planning'][15]="Vaše planiranje"; 
$LANG['planning'][16]="Informacije"; 
$LANG['planning'][17]="Za napraviti"; 
$LANG['planning'][18]="Učinjeno"; 

$LANG['plugins'][0]="Popis dodataka (Plugin)"; 
$LANG['plugins'][2]="Instalirano / nije konfigurirano"; 
$LANG['plugins'][3]="Instalirano / nije aktivirano"; 
$LANG['plugins'][4]="Greška / očisti"; 
$LANG['plugins'][5]="Nepostojeća funkcija(e)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serijski"; 
$LANG['printers'][15]="Paralelni"; 
$LANG['printers'][18]="Portovi"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Inicijalni brojač stranica"; 
$LANG['printers'][31]="Ispisano stranica"; 

$LANG['profiles'][0]="Globalna prava"; 
$LANG['profiles'][1]="Prava subjekta"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Kreiraj ticket"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Vidi sve tickete"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Čitaj"; 
$LANG['profiles'][11]="Piši"; 
$LANG['profiles'][12]="Nema pristupa"; 
$LANG['profiles'][13]="Standardni profil"; 
$LANG['profiles'][14]="Obriši ticket"; 
$LANG['profiles'][15]="Dodaj praćenje za sve tickete"; 
$LANG['profiles'][16]="Zadužen za ticket"; 
$LANG['profiles'][17]="Ukradi ticket"; 
$LANG['profiles'][18]="Ažuriraj ticket"; 
$LANG['profiles'][19]="Dodijeli ticket"; 
$LANG['profiles'][20]="Vidi osobna planiranja"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Administracija rezervacija"; 
$LANG['profiles'][24]="Ažuriraj zaporku"; 
$LANG['profiles'][26]="Vidi tickete kreirane od moje grupe"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekurzivan"; 
$LANG['profiles'][29]="Dinamičan"; 
$LANG['profiles'][30]="Vidi OCSNG informacije"; 
$LANG['profiles'][31]="Sinkroniziraj OCSNG ručno"; 
$LANG['profiles'][32]="Vidi dodijeljeni ticket (osobni + dodijeljen grupi)"; 
$LANG['profiles'][33]="Korisnik nije nađen"; 
$LANG['profiles'][34]="Zaglavlje"; 
$LANG['profiles'][35]="Ažuriraj sva praćenja"; 
$LANG['profiles'][36]="Vidi raspored ljudi moje grupe"; 
$LANG['profiles'][37]="Standardni subjekt"; 
$LANG['profiles'][38]="Vidljivost"; 
$LANG['profiles'][39]="Zaduženje"; 
$LANG['profiles'][40]="Ažuriraj"; 
$LANG['profiles'][41]="Kreiranje"; 
$LANG['profiles'][42]="Asocijacija"; 
$LANG['profiles'][43]="Korisnička metoda autorizacije i sinkronizacije"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Prihvatiti"; 
$LANG['registry'][2]="Putanja"; 
$LANG['registry'][3]="Ključ/vrijednost"; 
$LANG['registry'][4]="Registry ključ(evi) nađen(i)"; 
$LANG['registry'][5]="Ključ nije nađen u registry-u"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Osobna bilješka"; 
$LANG['reminder'][1]="Javna bilješka"; 
$LANG['reminder'][6]="Nova bilješka"; 
$LANG['reminder'][9]="Tekst"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Bez naziva"; 
$LANG['reminder'][16]="Globalna bilješka"; 

$LANG['reports'][0]="Odaberite izvješće koje želite izraditi"; 
$LANG['reports'][4]="Popis uređaja pod ugovorom"; 
$LANG['reports'][11]="Uređaji pod ugovorom"; 
$LANG['reports'][12]="Tipovi uređaja"; 
$LANG['reports'][13]="Datum(i)"; 
$LANG['reports'][15]="Pokaži izvješće"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Standardno izvješće"; 
$LANG['reports'][27]="Po ugovoru"; 
$LANG['reports'][28]="Po godini"; 
$LANG['reports'][33]="Mrežno izvješće"; 
$LANG['reports'][36]="Spojeni uređaji"; 
$LANG['reports'][37]="Ispušteni"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Po lokaciji"; 
$LANG['reports'][41]="Po uređaju"; 
$LANG['reports'][42]="Po ispuštenom"; 
$LANG['reports'][46]="Portovi uređaja"; 
$LANG['reports'][47]="portovi uređaja"; 
$LANG['reports'][49]="Mrežno izvješće po uređajima"; 
$LANG['reports'][51]="Mrežno izvješće po ispuštenima"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Mrežno izvješće po lokaciji"; 
$LANG['reports'][57]="Popis materijala"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Datum otvaranja"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Ostale financijske informacije (licence, toneri, potrošni)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Artikli za rezervirati"; 
$LANG['reservation'][2]="Uređaj privremeno nedostupan"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Rezerviraj"; 
$LANG['reservation'][9]="Rezerviraj artikl"; 
$LANG['reservation'][16]="Do"; 
$LANG['reservation'][17]="Od"; 
$LANG['reservation'][18]="Traženi artikl je već rezerviran za traženo razdoblje"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modificiraj sadržaj"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Ponavljanje"; 
$LANG['reservation'][28]="Po tjednu"; 
$LANG['reservation'][29]="Po danu"; 
$LANG['reservation'][30]="vrijeme"; 
$LANG['reservation'][31]="Od"; 
$LANG['reservation'][35]="Buduće i trenutne rezervacije"; 
$LANG['reservation'][36]="Prošle rezervacije"; 
$LANG['reservation'][37]="Nema rezervacije"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Ovo će maknuti sve rezervacije u progresu."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="je"; 
$LANG['rulesengine'][1]="nije"; 
$LANG['rulesengine'][2]="sadrži"; 
$LANG['rulesengine'][3]="ne sadrži"; 
$LANG['rulesengine'][4]="kreni sa"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kriterij"; 
$LANG['rulesengine'][7]="Akcije"; 
$LANG['rulesengine'][8]="Pravila upravljanja"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Tip akcije"; 
$LANG['rulesengine'][12]="Polja"; 
$LANG['rulesengine'][13]="Vrijednost"; 
$LANG['rulesengine'][14]="Stanje"; 
$LANG['rulesengine'][15]="Razlog"; 
$LANG['rulesengine'][16]="Kriterij"; 
$LANG['rulesengine'][17]="Pravila"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Subjekti i prava na dodijeljivanje pravila"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Dodijeli"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Tip pravila"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Popis pravila"; 
$LANG['rulesengine'][30]="Akcija"; 
$LANG['rulesengine'][33]="Padajući riječnik"; 
$LANG['rulesengine'][35]="Programski riječnik"; 
$LANG['rulesengine'][36]="Riječnik proizvođaća"; 
$LANG['rulesengine'][37]="Pravila o dodijeljivanju kategorije programa"; 
$LANG['rulesengine'][38]="Preračunaj"; 
$LANG['rulesengine'][40]="kategorija"; 
$LANG['rulesengine'][41]="Validacija"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Dodijeli: IP adresu uređaju"; 
$LANG['rulesengine'][47]="Dodijeli: ime + domenu uređaju"; 
$LANG['rulesengine'][48]="Dodijeli opremu"; 
$LANG['rulesengine'][49]="Dodijeli: MAC adresu uređaju"; 
$LANG['rulesengine'][50]="Računalni model riječnika"; 
$LANG['rulesengine'][51]="Monitor model riječnik"; 
$LANG['rulesengine'][52]="Telefon model riječnik"; 
$LANG['rulesengine'][53]="Model periferije riječnik"; 
$LANG['rulesengine'][54]="Printer model riječnik"; 
$LANG['rulesengine'][55]="Mrežni model riječnik"; 
$LANG['rulesengine'][56]="Modeli"; 
$LANG['rulesengine'][60]="Računalni tip riječnika"; 
$LANG['rulesengine'][61]="Monitor tip riječnik"; 
$LANG['rulesengine'][62]="Telefon tip riječnik"; 
$LANG['rulesengine'][63]="Tip periferije riječnik"; 
$LANG['rulesengine'][64]="Printer tip riječnik"; 
$LANG['rulesengine'][65]="Mrežni uređaj tip riječnik"; 
$LANG['rulesengine'][66]="Tip"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Service Pack riječnik"; 
$LANG['rulesengine'][69]="OS verzija riječnika"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Ponovi riječnik"; 
$LANG['rulesengine'][77]="Riječnici"; 
$LANG['rulesengine'][78]="Verzija"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Globalni riječnik"; 
$LANG['rulesengine'][81]="Rezultati pravila"; 
$LANG['rulesengine'][82]="Detalji rezultata"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Testiraj pravila riječnika"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Program obrisan od GLPI riječnika"; 
$LANG['rulesengine'][90]="Rad u tijeku..."; 
$LANG['rulesengine'][91]="Kraj rada"; 
$LANG['rulesengine'][92]="Oprez kod pokretanja riječnika"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Odabir proizvođaća"; 
$LANG['rulesengine'][96]="Ponovi riječnik za proizvođaća(e)<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="Nema elemenata za testiranje"; 
$LANG['rulesengine'][100]="Keširaj informacije"; 
$LANG['rulesengine'][102]="Naziv pravila"; 
$LANG['rulesengine'][103]="Objekti u spremniku"; 
$LANG['rulesengine'][104]="Originalna vrijednost"; 
$LANG['rulesengine'][105]="Modificirana vrijednost"; 
$LANG['rulesengine'][106]="Nepromijenjeno"; 
$LANG['rulesengine'][107]="Neaktivan"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Dodijeljivanje prava"; 
$LANG['rulesengine'][111]="Dodjela subjekta"; 
$LANG['rulesengine'][112]="Dodijeljivanje prava i subjekata"; 
$LANG['rulesengine'][120]="Sustav je stao nakon prvog provjerenog pravila"; 
$LANG['rulesengine'][121]="Sustav tretira sva pravila."; 
$LANG['rulesengine'][122]="Sustav je prošao rezultat pravila vezan uz sljedeći"; 
$LANG['rulesengine'][130]="Subjekt iz LDAP"; 
$LANG['rulesengine'][131]="Subjekt po TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Traži"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="sadrži"; 
$LANG['search'][4]="sortirano po"; 
$LANG['search'][8]="Početni datum"; 
$LANG['search'][9]="Krajnji datum"; 
$LANG['search'][10]="u"; 
$LANG['search'][11]="Artikli nađeni"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Artikl nije nađen"; 
$LANG['search'][16]="Barem"; 
$LANG['search'][17]="Dodaj kriterij pretraživanja"; 
$LANG['search'][18]="Obriši kriterij traženja"; 
$LANG['search'][19]="Dodaj globalni kriterij pretraživanja"; 
$LANG['search'][20]="Obriši globalni kriterij pretraživanja"; 

$LANG['setup'][0]="Padajući meni"; 
$LANG['setup'][2]="Dodaj korisnika..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Tip računala"; 
$LANG['setup'][5]="Operativni sustavi"; 
$LANG['setup'][6]="Personalizacija"; 
$LANG['setup'][9]="Mrežno sučelje"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Sljedimo privatni kao standard"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Odaberi jezik"; 
$LANG['setup'][42]="Tip mreže"; 
$LANG['setup'][43]="Tip printera"; 
$LANG['setup'][44]="Tip monitora"; 
$LANG['setup'][45]="Tip kučišta"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Odaberite katogoriju za konfiguriranje"; 
$LANG['setup'][63]="Pažnja: vi ste na putu da obrišete zaglavlje korišteno od jednog ili više artikala"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Možete također zamijeniti sve događaje ovog zaglavlja sa drugim:"; 
$LANG['setup'][67]="Vanjska autorizacija"; 
$LANG['setup'][69]="Tip uređaja"; 
$LANG['setup'][70]="Generalna instalacija"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Mrežna točka"; 
$LANG['setup'][74]="Nemožete obrisati ovo mjesto, jer ima podstavke"; 
$LANG['setup'][75]="Kao podgrupa od"; 
$LANG['setup'][79]="Kategorija ticketa"; 
$LANG['setup'][80]="Tip vanjskog proizvođaća"; 
$LANG['setup'][81]="Zaglavlje dokumenta"; 
$LANG['setup'][82]="Tip kontakta"; 
$LANG['setup'][83]="Status artikla"; 
$LANG['setup'][84]="Tip tonera"; 
$LANG['setup'][85]="Tip ugovora"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Mreža"; 
$LANG['setup'][89]="Domena"; 
$LANG['setup'][90]="VLAN-i"; 
$LANG['setup'][91]="Model računala"; 
$LANG['setup'][92]="Tip potrošnog"; 
$LANG['setup'][93]="Hard disk sučelje"; 
$LANG['setup'][94]="Modeli monitora"; 
$LANG['setup'][95]="Mrežni model"; 
$LANG['setup'][96]="Modeli printera"; 
$LANG['setup'][97]="Periferni modeli"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Novi log-a"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2- Strog (Nije korišten)"; 
$LANG['setup'][105]="3- Important (successful logins)"; 
$LANG['setup'][106]="4- Zapažanja (Dodaj, obriši, praćenje)"; 
$LANG['setup'][107]="5- Kompletno (Sve)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Standardni jezik"; 
$LANG['setup'][114]="Boja prioriteta"; 
$LANG['setup'][115]="Standardni brojčani prag za tonere i potrošni"; 
$LANG['setup'][116]="Automatsko dodijeljivanje ticketa zaduženom tehničkom osoblju"; 
$LANG['setup'][117]="Dozvoliti anonimni pregled FAQ-a"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automatski dodaj korisnike iz vanjskog autentifikacijskog izvora"; 
$LANG['setup'][125]="... Iz vanjskog izvora"; 
$LANG['setup'][126]="Automatski dodaj korisnika iz vanjskog izvora"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Format datuma"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktiviraj OCSNG način"; 
$LANG['setup'][134]="OCSNG način"; 
$LANG['setup'][135]="Normalno"; 
$LANG['setup'][136]="Prijevod"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="Koristi GLPI u modu"; 
$LANG['setup'][139]="Uobičajeni"; 
$LANG['setup'][140]="Tipovi"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Korak za sat"; 
$LANG['setup'][149]="Broj decimala u iznosu"; 
$LANG['setup'][150]="Format broja"; 
$LANG['setup'][154]="Bazični"; 
$LANG['setup'][155]="rootdn (za anonimne veze)"; 
$LANG['setup'][156]="Prolaz (za prijavljene poveznice)"; 
$LANG['setup'][157]="LDAP ekstenzije vašeg PHP parsera nije instaliran"; 
$LANG['setup'][158]="Nemoguće koristiti LDAP kao vanjski izvor konekcije"; 
$LANG['setup'][159]="Filter konekcije"; 
$LANG['setup'][162]="IMAP/POP konfiguracija"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="Vaš PHP parser je kompajliran bez podrške za IMAP"; 
$LANG['setup'][166]="Nemoguće korištenje IMAP/POP kao vanjskog izvora konekcije"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Opcije konekcije"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (opcija)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Korijenska mapa (opcija)"; 
$LANG['setup'][177]="CAS konfiguracija"; 
$LANG['setup'][178]="CURL ili DOMXML ekstenzija za vaš PHP parser nije instalirana"; 
$LANG['setup'][179]="Nemoguće koristiti CAS kao vanjski izvor konekcije"; 
$LANG['setup'][180]="Koristi TLS"; 
$LANG['setup'][181]="ldap_start_tls ne postoji"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Vremenska zona"; 
$LANG['setup'][190]="x509 certifikat"; 
$LANG['setup'][191]="email atributi za x509"; 
$LANG['setup'][192]="Omogućeno"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Zadrži status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Kopiraj status računala"; 
$LANG['setup'][198]="Postavi status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator email"; 
$LANG['setup'][204]="Email potpis"; 
$LANG['setup'][205]="Email poslan administratoru"; 
$LANG['setup'][206]="Neuspješno slanje email-a administratoru"; 
$LANG['setup'][207]="Administrator odgovara na email (ako je potrebno)"; 
$LANG['setup'][217]="PHP mail funkcija je nepoznata ili nije aktivirana na Vašem sistemu"; 
$LANG['setup'][218]="Korištenje SMTP-a je potrebno"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Limit rasporeda za planiranje"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Koristi SMTP server za slanje email poruka"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP zaporka"; 
$LANG['setup'][236]="Bivši tehničar zadužen za ticket"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Tehničar zadužen za ovaj ticket"; 
$LANG['setup'][240]="Opcije obavijesti"; 
$LANG['setup'][241]="Nema osobnog kriterija. Kreirati osobne parametre?"; 
$LANG['setup'][242]="Opcije alarma"; 
$LANG['setup'][243]="Alarm na potrošni"; 
$LANG['setup'][244]="Alarm na tonere"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alarm na ugovore"; 
$LANG['setup'][247]="Alarm na financijske informacije"; 
$LANG['setup'][248]="Grupa zadužena za ticket"; 
$LANG['setup'][249]="Grupa tražitelja"; 
$LANG['setup'][250]="Standardni popis polja za pretraživanje"; 
$LANG['setup'][252]="Odaberi standardne artikle za prikaz"; 
$LANG['setup'][253]="Filter za pretraživanje u grupi"; 
$LANG['setup'][254]="Tip pretraživanja"; 
$LANG['setup'][255]="Grupni atributi sadržani u korisnicima"; 
$LANG['setup'][256]="U korisnicima"; 
$LANG['setup'][257]="U grupi"; 
$LANG['setup'][258]="Korisnici i grupe"; 
$LANG['setup'][259]="Pripada grupi"; 
$LANG['setup'][260]="Korisnički atributi sadrže grupu"; 
$LANG['setup'][261]="DN grupe"; 
$LANG['setup'][262]="Koristi DN u pretraživanju"; 
$LANG['setup'][263]="Pretraživački filter za korisnike"; 
$LANG['setup'][264]="Alarm kod isteklih licenci"; 
$LANG['setup'][271]="Zabrani upravljanje monitorima"; 
$LANG['setup'][272]="Zabrani upravljanje uređajima"; 
$LANG['setup'][273]="Zabrani upravljanje telefonima"; 
$LANG['setup'][274]="za ručno dodavanje"; 
$LANG['setup'][275]="Zabrani upravljanje printerima"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopiraj"; 
$LANG['setup'][284]="Očisti"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Provjeriti postoji li nova verzija"; 
$LANG['setup'][301]="Nova verzija je raspoloživa:"; 
$LANG['setup'][302]="Naći čete na stranicama GLPI-PROJECT.org"; 
$LANG['setup'][303]="Imate zadnju raspoloživu verziju"; 
$LANG['setup'][304]="Konekcija neuspjela. Ako koristite proxy, molim konfigurirajte."; 
$LANG['setup'][305]="Svaki dan"; 
$LANG['setup'][306]="Provjeri nadogradnju"; 
$LANG['setup'][307]="Nikad"; 
$LANG['setup'][308]="Svaki tjedan"; 
$LANG['setup'][309]="Svaki mjesec"; 
$LANG['setup'][310]="Neuspješno konektiranje na stranice."; 
$LANG['setup'][311]="Neuspješna konekcija na proxy server"; 
$LANG['setup'][312]="Nema raspoloživih podataka na web stranici"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Veza sa artiklima za kreiranje ticketa"; 
$LANG['setup'][351]="Svi artikli"; 
$LANG['setup'][352]="Vezivni artikli za ticket"; 
$LANG['setup'][360]="Automatska polja (označena sa *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Standardno zaglavlje kod dodavanja dokumenta u ticket"; 
$LANG['setup'][503]="Modeli telefona"; 
$LANG['setup'][504]="Tip telefona"; 
$LANG['setup'][505]="Tip napajanja za telefone"; 
$LANG['setup'][601]="LDAP vrijednost"; 
$LANG['setup'][602]="Konekcija na OCSNG bazu"; 
$LANG['setup'][603]="Dodaj korisnika"; 
$LANG['setup'][604]="Asocijacija na grupu"; 
$LANG['setup'][606]="Nemogu dodati. Korisnik već postoji."; 
$LANG['setup'][607]="Asocijacija na profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Obavezan naziv ticketa"; 
$LANG['setup'][611]="Obavezan sadržaj ticketa"; 
$LANG['setup'][612]="Obavezna kategorija ticketa"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Veza"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Generalni"; 
$LANG['setup'][704]="Obavijest"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replikacija"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Baza"; 
$LANG['setup'][803]="Razlika između master i slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave baza nije u sinkronizaciji!"; 
$LANG['setup'][809]="MySql replika: read only"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Verzija kupnje"; 
$LANG['software'][2]="Koristi verziju"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Neograničeno"; 
$LANG['software'][5]="Verzije"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Dodaj verziju"; 
$LANG['software'][8]="Dodaj licencu"; 
$LANG['software'][11]="Licence"; 
$LANG['software'][17]="Instalirani programi"; 
$LANG['software'][19]="Instalacije"; 
$LANG['software'][20]="Preostalo"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Ažuriranje"; 
$LANG['software'][30]="Tip licence"; 
$LANG['software'][32]="Istek roka"; 
$LANG['software'][44]="Instaliraj program"; 
$LANG['software'][45]="Deinstalacija programa"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Povezivanje"; 
$LANG['software'][48]="Povezivanje"; 
$LANG['software'][49]="Program bačen u smeće nakon povezivanja"; 
$LANG['software'][50]="Dodijeljeno računalu"; 
$LANG['software'][51]="Broj mora biti 1 kako bi bilo efekta"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Kategorija programa"; 

$LANG['state'][0]="Status"; 
$LANG['state'][6]="Tip artikla"; 
$LANG['state'][7]="Artikl nije nađen"; 
$LANG['state'][11]="Ukupno"; 

$LANG['stats'][0]="Odaberite statistiku za prikaz"; 
$LANG['stats'][1]="Globalno"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Po artiklu"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Prosiječno vrijeme riješavanja"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Broj riješenih ticketa"; 
$LANG['stats'][13]="Broj ticketa"; 
$LANG['stats'][15]="Prosiječno vrijeme riješavanja"; 
$LANG['stats'][16]="Ime tehničara"; 
$LANG['stats'][20]="Korisničko ime"; 
$LANG['stats'][23]="Statistika nije raspoloživa"; 
$LANG['stats'][25]="Prosiječno (realno) trajanje ticketa"; 
$LANG['stats'][27]="Ukupno (realno) trajanje ticketa"; 
$LANG['stats'][30]="Prosiječno vrijeme odgovora na ticket"; 
$LANG['stats'][31]="Dan(i)"; 
$LANG['stats'][33]="Minuta(e)"; 
$LANG['stats'][34]="Sekunda(e)"; 
$LANG['stats'][35]="Ticket(i)"; 
$LANG['stats'][44]="Ime dobavljača"; 
$LANG['stats'][45]="Po uređaju"; 
$LANG['stats'][47]="po ticketu"; 
$LANG['stats'][48]="(dodijeljen)"; 
$LANG['stats'][49]="(praćenje)"; 

$LANG['title'][5]="Baza znanja"; 
$LANG['title'][6]="Mreža"; 
$LANG['title'][9]="Status artikla"; 
$LANG['title'][10]="Praćenje ticketa"; 
$LANG['title'][13]="Informacije o korisnicima"; 
$LANG['title'][14]="Vanjski izvori prijave"; 
$LANG['title'][24]="Asistencija"; 
$LANG['title'][26]="Glavni"; 
$LANG['title'][27]="Konekcije"; 
$LANG['title'][28]="Ticketi"; 
$LANG['title'][30]="Komponente"; 
$LANG['title'][33]="Vanjske veze"; 
$LANG['title'][34]="Veze"; 
$LANG['title'][37]="Bilješke"; 
$LANG['title'][38]="Povijesno"; 
$LANG['title'][40]="Javne i privatne bilješke"; 
$LANG['title'][42]="Masivna modifikacija"; 
$LANG['title'][43]="Registry"; 

$LANG['tracking'][1]="Moji uređaji"; 
$LANG['tracking'][2]="Ili završite traženje"; 
$LANG['tracking'][3]="Krivi datum. Nadogradnja otkazana."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Nema opisa ticketa, molim ponovite"; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Dokumentiraj ticket"; 
$LANG['tracking'][29]="Broj"; 
$LANG['tracking'][30]="Novo"; 
$LANG['tracking'][31]="Procesiranje (dodijeljeno)"; 
$LANG['tracking'][32]="Procesiranje (planirano)"; 
$LANG['tracking'][34]="Direktno"; 
$LANG['tracking'][35]="Napisano"; 
$LANG['tracking'][37]="Zadržite tickete kada brišete opremu iz inventorija"; 
$LANG['tracking'][38]="Email je poslan"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Prenošenje"; 
$LANG['transfer'][3]="Ako nije korišten"; 
$LANG['transfer'][4]="Isprazniti listu elemenata koji će biti transferirani"; 
$LANG['transfer'][5]="Možete nastaviti sa dodavanjem elemenata za transfer ili transferirajte sada te elemente"; 
$LANG['transfer'][6]="Razmislite o izradi kopije (backup) prije transfera artikala."; 
$LANG['transfer'][7]="Artikl za transfer"; 
$LANG['transfer'][8]="Model transfera"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Greška tijekom ažuriranja baze"; 
$LANG['update'][91]="Oprez!"; 
$LANG['update'][92]="Ažuriraćete GLPI bazu :"; 
$LANG['update'][93]="Konekcija na bazu uspješna"; 
$LANG['update'][94]="Ažuriranje uspješno, vaša baza je up to date"; 
$LANG['update'][95]="Konekcija na bazu neuspjela, provjerite parametre spajanja uključene u config_db.php datoteci"; 
$LANG['update'][96]="Sada, svi administratori imaju 'super-admin' ovlasti. Ovaj novi tip korisnika je također dodan."; 
$LANG['update'][105]="Nemoguće dovršiti ažuriranje, na ovaj način !!"; 
$LANG['update'][106]="Idi nazad na GLPI"; 
$LANG['update'][107]="Morate sada nastaviti sa ažuriranjem sadržaja baze"; 
$LANG['update'][130]="Ažuriranje lokacija"; 
$LANG['update'][131]="Nova struktura je hijerarhijska"; 
$LANG['update'][132]="Ako koristite delimitirajući karakter, možete podesiti način generiranja nove hijerarhije."; 
$LANG['update'][133]="Specificirajte korijensku lokaciju koja uključuje sve generirane lokacije."; 
$LANG['update'][134]="Delimitirajući karakter"; 
$LANG['update'][135]="Root lokacija"; 
$LANG['update'][136]="Ovo je nova hijerarhija. Ako je u redu, možete validirati."; 
$LANG['update'][137]="Nova hijerarhija"; 
$LANG['update'][138]="Aktualna lokacija"; 
$LANG['update'][139]="Optimizacija tablice"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Naziv"; 
$LANG['users'][2]="Kategorija"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>